@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package WWW::ipinfo;
-$WWW::ipinfo::VERSION = '0.02';
+$WWW::ipinfo::VERSION = '0.03';
 use HTTP::Tiny;
 use 5.008;
 use JSON;
@@ -17,12 +17,15 @@ BEGIN {
 }
 
 
+
 sub get_ipinfo {
-    my $response = HTTP::Tiny->new->get('http://ipinfo.io/json');
+    my $ip = shift;
+    my $url = $ip ? "http://ipinfo.io/$ip/json" : "http://ipinfo.io/json";
+    my $response = HTTP::Tiny->new->get($url);
     die join(' ', 'Error fetching ip: ',
                   ($response->{status} or ''),
                   ($response->{reason} or '')) unless $response->{success};
-   decode_json($response->{content}); 
+   decode_json($response->{content});
 }
 
 
@@ -40,7 +43,7 @@ WWW::ipinfo - Returns your ip address and geolocation data using L<http://ipinfo
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -57,7 +60,7 @@ Exports the C<get_ipinfo> function.
 
 =head2 get_ipinfo
 
-Returns a hashref containing your ip and geolocation data:
+Returns a hashref containing ip and geolocation data. Optionally you can provide an ip address argument to get a hashref for an IP that is not your own. Works with IPv4 and IPv6 addresses.
 
     {
       ip        => "198.115.6.53",
@@ -74,8 +77,11 @@ Example
 
     use WWW::ipinfo;
 
-    my $ipinfo = get_ipinfo();
-    my $ip = $ipinfo->{ip};
+    my $ipinfo = get_ipinfo(); # get IP info for your IP address
+    my $ip = $ipinfo->{ip}; # your IP address
+
+    my $other_ipinfo = get_ipinfo('FE80::0202:B3FF:FE1E:8329'); #works with IPv6 addresses
+    my $country = $other_ipinfo->{country};
 
 =head1 SEE ALSO
 
